@@ -26,6 +26,9 @@ FAILEDOPERATION_STARTJOBFAILED = 'FailedOperation.StartJobFailed'
 # 当前状态冲突，不能执行该操作。
 FAILEDOPERATION_STATUSINCONFLICT = 'FailedOperation.StatusInConflict'
 
+# 当前状态不允许操作。
+FAILEDOPERATION_STATUSINCONFLICTERROR = 'FailedOperation.StatusInConflictError'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -44,6 +47,9 @@ INTERNALERROR_DATABASEERROR = 'InternalError.DatabaseError'
 # 迁移任务冲突。
 INTERNALERROR_DUPLICATEJOB = 'InternalError.DuplicateJob'
 
+# 内部组件访问错误。
+INTERNALERROR_INTERNALINNERCOMMONERROR = 'InternalError.InternalInnerCommonError'
+
 # 锁冲突。
 INTERNALERROR_LOCKERROR = 'InternalError.LockError'
 
